#!/bin/bash

###################################################################################################
# Simple shell script to read in the WSJT-X ADI format logfile and convert it to HTML for website #
#                                                                                                 #
# Mike T - M0AWS - 27/01/22                                                                       #
#                                                                                                 #
###################################################################################################

###################################################################################################
# History:                                                                                        #
#           v0.1 - 27/01/22 - MikeT - M0AWS - Intial code write                                   #
#           v0.2 - 28/01/22 - MikeT - M0AWS - Tidy up formatting                                  #
#                                                                                                 #
###################################################################################################

############################
# Global Vars

VERSION="v0.2"
CALLSIGN="M0AWS"
DATE=`date`
ADIFILENAME="./wsjtx_log.adi"
HTMLFILENAME="./WSJT_log.html"


############################
# Define Functions

function process_log() {

	tac $ADIFILENAME | while read LINE
	do
  	case $LINE in
		
		*call:*) DXCALL=`echo $LINE | awk '{print $1}' | awk -F">" '{print $2}'`
		 	 GRIDSQUARE=`echo $LINE | awk '{print $2}' | awk -F">" '{print $2}'`
		 	 MODE=`echo $LINE | awk '{print $3}' | awk -F">" '{print $2}'`
		 	 RSTSENT=`echo $LINE | awk '{print $4}' | awk -F">" '{print $2}'`
		 	 RSTRXD=`echo $LINE | awk '{print $5}' | awk -F">" '{print $2}'`
		 	 QSODATE=`echo $LINE | awk '{print $6}' | awk -F">" '{print $2}'`
		 	 TIMEON=`echo $LINE | awk '{print $7}' | awk -F">" '{print $2}'`
		 	 #QSODATEOFF=`echo $LINE | awk '{print $8}' | awk -F">" '{print $2}'`
		 	 TIMEOFF=`echo $LINE | awk '{print $9}' | awk -F">" '{print $2}'`
		 	 BAND=`echo $LINE | awk '{print $10}' | awk -F">" '{print $2}'`
		 	 FREQ=`echo $LINE | awk '{print $11}' | awk -F">" '{print $2}'`
		 	 #MYCALL=`echo $LINE | awk '{print $12}' | awk -F">" '{print $2}'`
		 	 #MYGRIDSQ=`echo $LINE | awk '{print $13}' | awk -F">" '{print $2}'`
		 	 TXPWR=`echo $LINE | awk '{print $14}' | awk -F">" '{print $2}'`
		 	 COMMENT=`echo $LINE | awk -F"<comment" '{print $2}' | awk -F">" '{print $2}' | sed 's/<eor//g'`
			 YEAR=`echo $QSODATE | cut -c 1-4`
			 MONTH=`echo $QSODATE | cut -c 5-6`
			 DAY=`echo $QSODATE | cut -c 7-8`
			 QSODATE=`echo "$DAY/$MONTH/$YEAR"`
			 TXPWR=`echo $TXPWR"w"`
			 TIMEON=`echo $TIMEON | sed 's/../&:/g;s/:$//'`
			 TIMEOFF=`echo $TIMEOFF | sed 's/../&:/g;s/:$//'`
			 FREQ=`echo $FREQ" Mhz"`

		 	 echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n</tr>" >> $HTMLFILENAME
		 	;;
  	esac
		
	done

}


function write_html_header() {
	echo -e "<!DOCTYPE html>\n<html>\n<style>\ntable, th, td {\n      border:1px solid black; }\n</style>\n<body>\n<center><h2>$CALLSIGN Digital Mode Log updated $DATE</h2></center>\n" > $HTMLFILENAME
	echo -e "<table style=\"width:100%\">\n<tr>\n<th>QSO DATE</th>\n<th>DX CALLSIGN</th>\n<th>DX GRID</th>\n<th>MODE</th>\n<th>RST SENT</th>\n<th>RST RXD</th>\n<th>TIME ON</th>\n<th>TIME OFF</th>\n<th>BAND</th>\n<th>FREQ</th>\n<th>TX PWR</th>\n<th>COMMENT</th>\n</tr>" >> $HTMLFILENAME
}


function write_html_footer() {
	echo -e "</table>\n<p>Web page generated by adi2html.sh $VERSION by M0AWS <a href=\"http://m0aws.co.uk\">http://m0aws.co.uk</a></p>\n</body>\n</html>\n" >> $HTMLFILENAME
}



############################
# main()

write_html_header
process_log
write_html_footer

